@@ -56,6 +56,11 @@ GdkColor *gtk_style_get_white_interp (GtkStyle *style);
 GdkColormap *gtk_widget_peek_colormap (void);
 
 void gtk_list_append_item (GtkList *list, GtkListItem *item);
-void gtk_list_prepend_item (GtkList *list, GtkListItem *item);
+
+gint gtk_input_add_interp (gint               source,
+			   GdkInputCondition  condition,
+			   GtkCallbackMarshal callback,
+			   gpointer           data,
+			   GtkDestroyNotify   destroy);
 
 #endif
