@@ -52,3 +52,13 @@ SCM scm_internal_cwdr (scm_catch_body_t body,
 
 #endif
 
+#ifndef HAVE_SCM_PUTS
+
+void
+scm_puts (char *str, SCM port)
+{
+  scm_gen_puts (scm_regular_string, str, port);
+}
+
+#endif
+
