@@ -3,8 +3,9 @@
 
 BEGIN_GNOME_DECLS
 
-struct gnome_desktop_entry {
+typedef struct {
 	char *exec;
+	char *tryexec;
 	char *icon_base;
 	char *docpath;
 	char *info;
@@ -15,11 +16,12 @@ struct gnome_desktop_entry {
 	/* These are computed from icon_base */
 	char *small_icon;
 	char *transparent_icon;
-};
+} GnomeDesktopEntry;
 
-struct gnome_desktop_entry *gnome_desktop_entry_load (char *file);
-void   gnome_desktop_entry_free   (struct gnome_desktop_entry *item);
-void   gnome_desktop_entry_launch (struct gnome_desktop_entry *item);
+GnomeDesktopEntry *gnome_desktop_entry_load (char *file);
+void gnome_desktop_entry_save (GnomeDesktopEntry *dentry);
+void gnome_desktop_entry_free (GnomeDesktopEntry *item);
+void gnome_desktop_entry_launch (GnomeDesktopEntry *item);
 
 int gnome_is_program_in_path (char *progname);
 
