@@ -18,7 +18,7 @@ char *g_unix_error_string (int error_num);
 char *g_concat_dir_and_file (const char *dir, const char *file);
 char *gnome_util_user_home(void);
 char *gnome_util_prepend_user_home(char *file);
-gchar *gnome_util_home_file(char *file);
+char *gnome_util_home_file(char *file);
 
 END_GNOME_DECLS
 
