@@ -7,6 +7,9 @@
 #include "libgnome/gnome-config.h"
 #include "libgnome/gnome-dns.h"
 #include "libgnome/gnome-dentry.h"
+#include "libgnome/gnome-i18n.h"
+#include "libgnome/gnome-string.h"
+#include "libgnome/gnome-triggers.h"
 
 extern char *gnome_user_home_dir;
 extern char *gnome_user_dir;
