@@ -3,9 +3,6 @@
 #include "gnome-colors.h"
 
 
-#define RESERVED_ENTRIES 10
-
-
 GdkVisual   *gnome_visual = NULL;
 GdkColormap *gnome_colormap = NULL;
 
@@ -27,9 +24,6 @@ gulong *gnome_lookup_blue;
 gulong *gnome_color_pixel_vals;
 gulong *gnome_gray_pixel_vals;
 
-static int     reserved_entries = RESERVED_ENTRIES;
-static gulong *reserved_pixels;
-
 static double gamma_val         = 1.0; /* FIXME: these should be read from the configuration files */
 static int color_cube_shades[4] = { 6, 6, 4, 24 };
 static int install_cmap         = FALSE;
@@ -38,15 +32,9 @@ static int install_cmap         = FALSE;
 static void
 set_app_colors (void)
 {
-	if (gnome_visual->depth == 8) {
-		gnome_black_pixel = reserved_pixels[0];
-		gnome_gray_pixel  = reserved_pixels[1];
-		gnome_white_pixel = reserved_pixels[2];
-	}
-
-	gnome_colors_store_color(&gnome_black_pixel, 0, 0, 0);
-	gnome_colors_store_color(&gnome_gray_pixel, 127, 127, 127);
-	gnome_colors_store_color(&gnome_white_pixel, 255, 255, 255);
+	gnome_black_pixel = gnome_colors_get_pixel(0, 0, 0);
+	gnome_gray_pixel  = gnome_colors_get_pixel(127, 127, 127);
+	gnome_white_pixel = gnome_colors_get_pixel(255, 255, 255);
 }
 
 
@@ -80,7 +68,6 @@ gnome_colors_init(void)
 				   color_cube_shades[2],
 				   color_cube_shades[3]);
 	gtk_preview_set_install_cmap(install_cmap);
-	gtk_preview_set_reserved(reserved_entries);
 
 	gtk_widget_set_default_visual(gtk_preview_get_visual());
 	gtk_widget_set_default_colormap(gtk_preview_get_cmap());
@@ -91,7 +78,6 @@ gnome_colors_init(void)
 	gnome_colormap         = info->cmap;
 	gnome_color_pixel_vals = info->color_pixels;
 	gnome_gray_pixel_vals  = info->gray_pixels;
-	reserved_pixels        = info->reserved_pixels;
 
 	gnome_red_ordered_dither   = info->dither_red;
 	gnome_green_ordered_dither = info->dither_green;
