@@ -8,13 +8,9 @@ GnomePropertyConfigurator *
 gnome_property_configurator_new (void)
 {
 	GnomePropertyConfigurator *this = g_malloc (sizeof (GnomePropertyConfigurator));
-	GtkWidget *notebook;
-
-	notebook = gtk_notebook_new ();
 
 	this->props = NULL;
-	
-	this->notebook = notebook;
+	this->notebook = NULL;
 
 	return this;
 }
@@ -22,7 +18,8 @@ gnome_property_configurator_new (void)
 void
 gnome_property_configurator_destroy (GnomePropertyConfigurator *this)
 {
-	gtk_widget_destroy (this->notebook);
+	if (this->notebook)
+		gtk_widget_destroy (this->notebook);
 	g_list_free (this->props);
 }
 
@@ -30,16 +27,16 @@ gnome_property_configurator_destroy (GnomePropertyConfigurator *this)
 
 void
 gnome_property_configurator_register (GnomePropertyConfigurator *this,
-				      GtkWidget *title_widget, GtkWidget *content_widget,
 				      int (*callback)(GnomePropertyRequest))
 {
-	// printf ("adding %x\n", callback);
 	this->props = g_list_append (this->props, callback);
+}
 
-	gtk_notebook_append_page (GTK_NOTEBOOK (this->notebook), content_widget, title_widget);
-
-	gtk_widget_show (content_widget);
-	gtk_widget_show (title_widget);
+void
+gnome_property_configurator_setup (GnomePropertyConfigurator *this)
+{
+	this->notebook = gtk_notebook_new ();
+	gtk_widget_show (this->notebook);
 }
 
 gint
@@ -48,6 +45,9 @@ gnome_property_configurator_request (GnomePropertyConfigurator *th,
 {
 	int (*cb)(GnomePropertyRequest);
 
+	if (!th->notebook)
+		return 0;
+
 	cb = (int (*)(GnomePropertyRequest))
 		(g_list_nth
 		 (th->props,
@@ -61,3 +61,16 @@ gnome_property_configurator_request (GnomePropertyConfigurator *th,
 	else
 		return 0;
 }
+
+static void
+request (int (*cb)(GnomePropertyRequest), GnomePropertyRequest r)
+{
+	(*cb) (r);
+}
+
+gint
+gnome_property_configurator_request_foreach (GnomePropertyConfigurator *th,
+					     GnomePropertyRequest r)
+{
+	g_list_foreach (th->props, (GFunc)request, (gpointer)r);
+}
