@@ -1,5 +1,5 @@
 #include <obgtk/obgtk.h>
-
+#include <gtkled.h>
 @interface GULPApp : Gtk_App
 {
 	PrintSystem *printsys;
@@ -20,6 +20,9 @@
 	Gtk_ScrolledWindow *listscroller;
 	Gtk_List *printerlist;
 	Gtk_ListItem **printers;
+	/* We should really write a wrapper for GtkLed */
+	Gtk_Misc **leds;
+	Gtk_Label **lbls;
 	
 	struct {
 		struct {
