@@ -469,7 +469,7 @@ show_applet_menu(GtkWidget *applet)
 
 	gtk_object_set_user_data(GTK_OBJECT(applet_menu), applet);
 
-	gtk_menu_popup(GTK_MENU(applet_menu), NULL, NULL, NULL, NULL, 3, 0);
+	gtk_menu_popup(GTK_MENU(applet_menu), NULL, NULL, NULL, NULL, 3, time(NULL));
 }
 
 
